<?php
namespace plugins\passwordless\controllers;

use \ActionController;
use \IoC;
use plugins\passwordless\services\SendLoginLink;
use plugins\passwordless\services\ValidatesLoginAttempt;

/**
 * Session controller
 * @author Jérôme Brilland
 * @version 1.0
 * @copyright (c) 2023, Jérôme Brilland
 * @license http://www.gnu.org/licenses/gpl.txt GNU General Public License
 */
class LoginController extends ActionController {
    
    protected function initialize() {
        $eventMediator = IoC::resolve( 'eventmediator' );
        $i18n = IoC::resolve( 'i18n' );
        $eventMediator->attach( 'empty_email', function() use ( $i18n ) {
            $this->flash['error'] = $i18n->__( 'email_cannot_be_empty' );
            $this->forward( 'plugins\\passwordless\\controllers\\LoginController', 'loginform' );
        } );
        
        $eventMediator->attach( 'invalid_email', function() use ( $i18n ) {
            $this->flash['error'] = $i18n->__( 'invalid_email' );
            $this->forward( 'plugins\\passwordless\\controllers\\LoginController', 'loginform' );
        } );
        
        $eventMediator->attach( 'invalid_login_link', function() use ( $i18n ) {
            $this->response->setStatus( 404 );
            $this->flash['error'] = $i18n->__( 'passwordless.invalid_link' );
            $this->forward( 'plugins\\passwordless\\controllers\\LoginController', 'loginform' );
        } );
    }
    
    public function doLoginForm() {
        $i18n = IoC::resolve( 'i18n' );
        $settings = IoC::resolve( 'settings' );
        $this->title = $i18n->__( 'log_in' ) . ' | ' . $settings['site_title'];
	}
	
    public function doSendLoginLink() {
        $i18n = IoC::resolve( 'i18n' );
        $settings = IoC::resolve( 'settings' );
        $email = $this->request->getParameters()->getString( 'email' );
        $sendLoginLink = new SendLoginLink( $email, $settings['passwordless.token_validity'] );
        $sendLoginLink->perform();
        $this->flash['notice'] = $i18n->__( 'passwordless.magic_link_sent', $email );
        $this->redirect( BASE_URL . 'auth/link' );
    }
    
    public function doLogin() {
        $i18n = IoC::resolve( 'i18n' );
        $settings = IoC::resolve( 'settings' );
        $token = $this->request->getAttribute( 'token', '' );
        $cookieToken = $this->request->getCookies()->getAlnum( 'lemoncms-magic-link-check' );
        $validatesLoginAttempt = new ValidatesLoginAttempt( $token, $cookieToken, $settings['passwordless.token_validity'] );
        $validatesLoginAttempt->perform();
        $returnTo = ( !empty( $_SESSION['return_to'] ) ) ? $_SESSION['return_to'] : BASE_URL;
        $this->flash['success'] = $i18n->__( 'successfully_logged_in' );
        $this->redirect( $returnTo );
    }
}
