<?php
namespace plugins\passwordless\services;

use \IoC;
use \Validator;
use plugins\passwordless\models\Magiclink;
use \DateTime;

class ValidatesLoginAttempt {
    
    private $token = null;
    private $cookieToken = null;
    private $tokenValidity = null;
    
    public function __construct( string $token, string $cookieToken, int $tokenValidity ) {
        $this->token = $token;
        $this->cookieToken = $cookieToken;
        $this->tokenValidity = $tokenValidity;
    }
    
    public function perform() {
        $eventMediator = IoC::resolve( 'eventmediator' );
        $magicLink = Magiclink::findOne( ['token' => $this->token, 'cookie_token' => $this->cookieToken] );
        if ( empty( $magicLink ) || $this->loginTokenExpired( $magicLink ) ) {
            $eventMediator->trigger( 'invalid_login_link' );
            return;
        }
        $user = $magicLink->user;
        
        $response = IoC::resolve( 'response' );
        $response->setCookie( 'lemoncms-magic-link-check', '', time() - 3600 );
        
        $magicLink->token = null;
        $magicLink->token_generated_at = null;
        $magicLink->cookie_token = null;
        $magicLink->save();
        
        $user->last_login = date( 'Y-m-d H:i:s' );
        $user->save();
        
        $_SESSION['user_id'] = $user->user_id;
        
        $eventMediator->trigger( 'after_login', $user );
    }
    
    private function loginTokenExpired( $magicLink ): bool {
        $now = new DateTime();
        $time = DateTime::createFromFormat( 'Y-m-d H:i:s', $magicLink->token_generated_at );
        return( $time->modify( '+2 hour' ) < $now );
    }
}
